function [A_est mu_xt] = delta_x_and_A_Inference(ss, initx,C,y,T,T1,N_per,noise)
%
%This function is complete step1: concentration inference and step2:
%network inference
%
% INPUT ARGUMENTS:
% 
%	ss          total number of species
%
%	initx      	initial condition of x
%
%	C          	measurement matrix
%
%	y          	combined measurements
%
%	T          	total number of time points
%
%	T1          number of time points in each perturbation
%
%	N_per       number of perturbations
%
%   noise       assumed variance of measurement noise
%
% OUTPUT ARGUMENTS:
%
%   A_est       inferred transition matrix A
%
%   mu_xt       inferred species concentrations x
%
%   x_delta  	inferred variation of species concentrations x


os = size(y,1);% number of combined measurements
delta_y = zeros(os,T-1); % variation of measurements
x_delta = zeros(ss,T-1); % variation of species

% settins of compressive sensing
OPTIONS = SB2_UserOptions('FixedNoise',false);
SETTINGS = SB2_ParameterSettings('NoiseStd',sqrt(noise));
% Step1: infer the variation of species
for t = 2:T
    delta_y(:,t-1) = y(:,t)-y(:,t-1);% variation of measurements
    % use compressive sensing to infer the variation of species
    PARAMETER = SparseBayes('Gaussian', C, delta_y(:,t-1),OPTIONS,SETTINGS);
    x_Lap = zeros(ss,1);  x_Lap(PARAMETER.Relevant) = PARAMETER.Value;
    x_delta(:,t-1) = x_Lap;  
end

% get x from x_delta
[mu_xt x_1_T_1 x_2_T] = xPerturbGather(ss,T,T1,N_per,initx,x_delta);

% Step: infer network A
A_est = zeros(ss,ss);
for i = 1:ss
    % use compressive sensing to infer each row of A
    [PARAMETER, HYPERPARAMETER, DIAGNOSTIC] = SparseBayes('Gaussian', x_1_T_1', x_2_T(i,:)');
    A_Lap = zeros(ss,1);  A_Lap(PARAMETER.Relevant) = PARAMETER.Value;
    A_est(i,:) = A_Lap';
end






