function [A5,A_var5] = extendBCS(ss,eta_inv,gamma1,beta)
%
% This function is to appply the extended Bayesian compressive sensing to
% infer A
%
% OUTPUT ARGUMENTS:
%
%	A5              inferred transition matrix
%
%	A_var5          variance of the inferred transition matrix

%
% INPUT ARGUMENTS:
% 
%	ss              number of species
%   
%	eta_inv         diagonal of Q
% 
%	gamma1,beta     statistics of x from xt_statistic.m
% 

alpha_prior5 = cell(ss,1); % hyperarameter of each row of transition matrix
% initialize all entries of hyper parameter to be 10
for ax = 1:ss
    temp = 10*ones(ss,1);
    alpha_prior5{ax} = diag(temp);
end


% interative steps to update hyperparameters
for n = 1:100
    A_var5 = cell(ss,1); % covariance of transition matrix
    A5 = zeros(ss,ss); % mean value of transition matrix
    % for each row of transition matrix
    for ax = 1:ss
        % update covariance
        A_var5{ax} = inv(gamma1/eta_inv(ax)+alpha_prior5{ax});
        % update mean 
        A5(ax,:) = beta(ax,:)* A_var5{ax}/eta_inv(ax);
    end
    % update hyperparameters
    for alpha_x = 1:ss
        A_var_x = A_var5{alpha_x};
        alpha_xy = zeros(1,ss);
        for alpha_y = 1:ss
            temp = A_var_x(alpha_y,alpha_y)+(A5(alpha_x,alpha_y))^2;
            alpha_xy(alpha_y) = 1/temp;
        end
        alpha_prior5{alpha_x} = diag(alpha_xy);
    end
end

