function result = pathway_inference(N_per,ss,os,T,T1,genNewC,noiseR,noiseQ,initx,y_all)
%
%This function is the main function to do pathway inference
%
% INPUT ARGUMENTS:
%
%	N_per	Number of perturbations
%
%	ss		total number of species
%
%	os		total number of combined measurements
%
%	T       total number of time points
%
%   T1      number of time points in each perturbation
%
%   genNewC if ==1,then Low-density parity-check code will generate new C
%
%   noiseR  assumed variance of measurement noise
%
%   noiseQ  assumed variance of process noise
%
%   initx   initial concentration of species. 
%
%   y_all   time-series of combined concentrations. 
%
% OUTPUT ARGUMENTS:
%
%   result  the inferred results

%% generate measurement matrix
if genNewC ==1 % Low-density parity-check code is used to generate measurement matrix
    C_cand = double(makeLdpc(os, ss, 1, 1, 3));
    % check whether all species are covered in measurement matrix
    if sum(sum(C_cand,1)==0)>0 ||sum(sum(C_cand,2)==0)>0
        sprintf('C is not well generated')
    else
        sprintf('C generated')
    end
else % load the existing measurement matrix
    load C_cand.mat
end

%% step1 and 2: Concentration inference and Network inference via compressive sensing
C = C_cand;% measurement matrix
y = [];
for k = 1:N_per
    y = [y,y_all{k}];
end

% use compressive sensing to infer concentrations and network
[A_own mu_xt] = delta_x_and_A_Inference(ss,initx,C,y,T,T1,N_per,noiseR);

% remove NaN entry in A_own
A_pred = A_own;
A_pred(isnan(A_pred)) = 0;

%% step3: Network refinement
[A_EBCS,sel_ind,A_EBCS_var] = networkRefinement(A_pred,ss,C,os,y,initx,...
    T,mu_xt,noiseR,noiseQ,N_per,T1);
% updated A with the selected time-variant related rows inferred by extended Bayesian compressive sensing
A_EBCS_whole = eye(ss);
A_EBCS_whole(sel_ind,sel_ind) = A_EBCS;

%% return results
result{1} = mu_xt; % step1: predicted x
result{2} = A_pred; % step2: predicted A
result{3} = sel_ind; % which row of A is selected in refinement step
result{4} = A_EBCS_whole;%step3: refined A
result{5} = A_EBCS_var;%step3: variance of refined A
