% generate combined measurements
function y = sample_lds_y(x, H, R, T)
% INPUT ARGUMENTS:
%
%	x           time-series of species concentrations in each perturbation
%
%	H           measurement matrix
%
%	R           covariance matrix of measurement noise
%
%	T           number of time points in each perturbation
%
% OUTPUT ARGUMENTS:
%
%   y           time-series of combined measurement concentrations in each perturbation


[os ss] = size(H);% find number of species and measurements

% randomly generate measuremnt noise from Gaussian distributions
obs_noise_samples = sample_gaussian(zeros(length(R),1), R, T)';

y = zeros(os, T);
% measurement at initial time point
y(:,1) = H*x(:,1) + obs_noise_samples(:,1);
% time-series of combined measurements
for t=2:T
  y(:,t) = H*x(:,t)  + obs_noise_samples(:,t);
end


