function [mu_xt,sigma_xt] = xInference(ss,x,R,C,y,T)
%
%This function is to
%
% INTPUT ARGUMENTS:
% 
%	ss          number of species
% 
%	x           inferred concentrations of species from step1
% 
%	R           covariance matrix of measurement noise
% 
%	C           updated measurement matrix
% 
%	y           updated measurements
% 
%	T           number of time points in each iteration
%
% OUTTPUT ARGUMENTS:
% 
%	mu_xt       mean values of x
%
%   sigma_xt    covariance of x


Var_x0 = 0.0001*eye(ss);
mu_x_real = mean(x,2);% mean value of x across time
state_noise_samples = sample_gaussian(zeros(ss,1), Var_x0, 1)';% random noise
mu_x = mu_x_real.*(1+state_noise_samples);% mean value of x across time with small noise
var_x = var(x');% variance of x across time
var_x(var_x==0) = 0.01; % assign a small to zero variance entry

% Bayesian linear regression to infer x
ga_x = inv(diag(var_x*10));%inverse of diagonal of covariance x. To avoid strict constraints, we use 10*real covariance
L = inv(R);
sigma_xt = inv(ga_x+C'*L*C);
mu_xt = zeros(ss,T);
for t = 1:T
    mu_xt(:,t) = sigma_xt*(C'*L*y(:,t)+ga_x*mu_x);
end


