function [mu_xt x_1_T_1 x_2_T] = xPerturbGather(ss,T,T1,N_per,initx,x_delta)
% get x from x_delta
%
% INPUT ARGUMENTS:
% 
%	ss          total number of species
%
%	T          	total number of time points
%
%	T1          number of time points in each perturbation
%
%	N_per       number of perturbations
%
%	initx      	initial condition of x
%
%   x_delta  	inferred variation of species concentrations x
%
% OUTPUT ARGUMENTS:
% 
%	mu_xt       species concentration x from 1 to T
%
%	x_1_T_1     species concentration x where the the value at T1 in every
%               perturbation is removed
%
%	x_2_T       species concentration x where the the value at 1 in every
%               perturbation is removed


mu_xt = zeros(ss,T);
for n = 1:N_per
    initx_n = initx{n};
    x_delta_n = x_delta(:,(n-1)*T1+1:n*T1-1);% get 1:T1-1 of x_delta in each perturbation
    
    mu_xt_n = zeros(ss,T1);
    mu_xt_n(:,1) = initx_n;% initial concentraion of each perturbation
    % get x from 1 to T
    for t = 2:T1
        mu_xt_n(:,t) = mu_xt_n(:,t-1)+x_delta_n(:,t-1);
    end
    mu_xt(:,(n-1)*T1+1:n*T1) = mu_xt_n;% put all perturbations together
end

x_1_T_1 = mu_xt;
x_1_T_1(:,T1:T1:T) = [];% remove the value at T1 in each perturbation
x_2_T = mu_xt;
x_2_T(:,1:T1:T-T1+1) = [];% remove the value at 1 in each perturbation

