function [gamma1  beta]=xt_statistic(ss,mu_xt,sigma_xt,T1,N_per)
%
% This function is to calculate some statistics of x
%
% OUTTPUT ARGUMENTS:
% 
%	gamma1      sum of mu_xt1(:,t)*mu_xt1(:,t)'+ sigma_xt1 from t=1 to T1-1
%
%	beta        sum of mu_xt1(:,t)*mu_xt1(:,t-1)'+ sigma_xt1 from t=2 to T1
%
% INPUT ARGUMENTS:
% 
%	ss          number of species
% 
%	mu_xt       inferred mean value of x from linear Bayesian regression
% 
%	sigma_xt    inferred covariance of x from linear Bayesian regression 
% 
%	T1      	number of time points in each perturbation
% 
%	N_per      	Number of perturbations


gamma1 = zeros(ss, ss);
beta = zeros(ss, ss);

for n = 1:N_per
    sigma_xt1 = sigma_xt{n};
    mu_xt1 = mu_xt{n};
    for t = 1:T1
        if t<T1
            gamma1 = gamma1 + mu_xt1(:,t)*mu_xt1(:,t)' + sigma_xt1;
        end
        if t>1
            beta = beta + mu_xt1(:,t)*mu_xt1(:,t-1)'+ sigma_xt1 ;
        end
    end
end
